@@ -1,5 +1,7 @@
+#! /usr/bin/env python
 # This file mainly exists to allow python setup.py test to work.
-import os, sys
+import os
+import sys
 os.environ['DJANGO_SETTINGS_MODULE'] = 'example.settings'
 test_dir = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 sys.path.insert(0, test_dir)
@@ -7,6 +9,7 @@ sys.path.insert(0, test_dir)
 from django.test.utils import get_runner
 from django.conf import settings
 
+
 def runtests():
     TestRunner = get_runner(settings)
     test_runner = TestRunner(verbosity=1, interactive=True)
